/*******************************************************************************
 * Copyright (c) 2000, 2005 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 * Port to the D programming language:
 *     Thomas Graber <d4rkdragon@gmail.com>
 *******************************************************************************/
module dwtexamples.texteditor.Images;

import dwt.dwthelper.InputStream;

import dwt.graphics.Image;
import dwt.graphics.ImageData;
import dwt.widgets.Display;
import dwt.dwthelper.ByteArrayInputStream;

import tango.core.Exception;
import tango.io.Stdout;

public class Images {

    // Bitmap Images
    public Image Bold;
    public Image Italic;
    public Image Underline;
    public Image Strikeout;
    public Image Red;
    public Image Green;
    public Image Blue;
    public Image Erase;
    
    Image[] AllBitmaps;
    
    this () {
    }

    public void freeAll () {
        for (int i=0; i<AllBitmaps.length; i++) AllBitmaps [i].dispose ();
        AllBitmaps = null;
    }

    Image createBitmapImage(Display display, void[] iImage, void[] iMask) { 
        InputStream sourceStream = new ByteArrayInputStream(cast(byte[]) iImage);
        InputStream maskStream  = new ByteArrayInputStream(cast(byte[])iMask ); 
                
        ImageData source = new ImageData (sourceStream);
        ImageData mask = new ImageData (maskStream);
        Image result = new Image (null, source, mask);
        try {
            sourceStream.close ();
            maskStream.close ();
        } catch (IOException e) {
            Stderr.formatln( "Stacktrace: {}", e.toString );
        }
        return result;
    }
    
    public void loadAll (Display display) {
        // Bitmap Images
        Bold = createBitmapImage (display, import( "bold.bmp" ), import( "bold_mask.bmp" ));
        Italic = createBitmapImage (display, import( "italic.bmp" ), import( "italic_mask.bmp" ));
        Underline = createBitmapImage (display, import( "underline.bmp" ), import( "underline_mask.bmp" ));
        Strikeout = createBitmapImage (display, import( "strikeout.bmp" ), import( "strikeout_mask.bmp" ));
        Red = createBitmapImage (display, import( "red.bmp" ), import( "red_mask.bmp" ));
        Green = createBitmapImage (display, import( "green.bmp" ), import( "green_mask.bmp" ));
        Blue = createBitmapImage (display, import( "blue.bmp" ), import( "blue_mask.bmp" ));
        Erase = createBitmapImage (display, import( "erase.bmp" ), import( "erase_mask.bmp" ));
        
        AllBitmaps = [ Bold,
                       Italic,
                       Underline,
                       Strikeout,
                       Red,
                       Green,
                       Blue,
                       Erase
                      ];
    }
}
